#!/bin/bash

pwd=$(pwd)

export PS1='\w\$ '
umask 022

export PATH=$pwd:$PATH
export LD_LIBRARY_PATH=$pwd/lib:$LD_LIBRARY_PATH

version="01"

if [ ! -e $HOME/.minecraft ]
then
 echo "--------------------------------------------------------------"
 echo "mkdir .minecraft"
 mkdir $HOME/.minecraft
fi

if [ -e $HOME/.minecraft/.version ];then
 lastrun=`cat $HOME/.minecraft/.version`
else
 lastrun="00"
fi

#all done, write the new lastrun...
if [ ! "$version" = "$lastrun" ];then
        echo "$version">$HOME/.minecraft/.version
fi

#checking Presence of the Launcher
if [ ! -d $HOME/.minecraft/launcher ];then
        mkdir -p $HOME/.minecraft/launcher
fi

if [ ! -e $HOME/.minecraft/.launcher ];then
         echo "Asking for launcher"
         zenity --question --title="Minecraft Launcher" --text="You will need to copy your Minecraft Launcher somewhere.
         A new folder in appdata/minecraft called launcher has been created for that,
         but you can put it where you want

         is the launcher copied somewhere?"
         if [ $? = "0" ];then
                LAUNCHER=`zenity --file-selection --file-filter=" "*.exe" "*.jar" "`
                case $? in
                                 0)
                                                echo "$LAUNCHER" selected.
                                                echo "$LAUNCHER">$HOME/.minecraft/.launcher;;
                                 1)
                                                echo "No file selected."
                                                exit
                                                ;;
                                -1)
                                                echo "No file selected."
                                                exit
                                                ;;
                esac
         else
             exit
         fi
fi

export LAUNCHER="`cat $HOME/.minecraft/.launcher`"

if [ ! -e $HOME/.minecraft/.params ];then
        echo "-server  -Xbatch -Xms512M -Xnoclassgc">$HOME/.minecraft/.params
fi

if [ ! -e "$LAUNCHER" ];then
        rm $HOME/.minecraft/.launcher
         zenity --error --title="Minecraft Launcher" --text="The Launcher cannot be found anymore.
         Please relaunch to re-set it"
         exit
fi

#export LIBGL_FB=0
#export LIBGL_SHRINK=2
export LIBGL_MIPMAP=3
#export LIBGL_ALPHAHACK=1
#export LIBGL_STREAM=1
#export LIBGL_BATCH=1
export LIBGL_BLENDHACK=1
#export LIBGL_NOLUMALPHA=1
#export LIBGL_VERSION="1.2"

if [ -e .shrink ];then
 LIBGL_SHRINK=`cat .shrink`
fi
if [ -e .mipmap ];then
 LIBGL_MIPMAP=`cat .mipmap`
fi
if [ -e .batch ];then
 LIBGL_BATCH=`cat .batch`
fi
if [ -e .nolumalpha ];then
 LIBGL_NOLUMALPHA=`cat .nolumalpha`
fi
if [ -e .string ];then
 LIBGL_VERSION=`cat .string`
fi

free=`free -mt | grep Total | awk '{print $4}'`
echo System check
echo ============
echo Freememory is $free
echo Launcher = $LAUNCHER
echo LIBGL_FB=$LIBGL_FB
echo LIBGL_MIPMAP=$LIBGL_MIPMAP
echo LIBGL_SHRINK=$LIBGL_SHRINK
echo LIBGL_BATCH=$LIBGL_BATCH
echo LIBGL_BLENDHACK=$LIBGL_BLENDHACK
echo LIBGL_VERSION=$LIBGL_VERSION

#export JDK="$pwd/jdk/jre/bin/java"
export JAVA_HOME=$HOME/.minecraft/java/
export JRE_HOME=$JAVA_HOME/jre
export PATH=$JRE_HOME/bin:$PATH
export JDK=java
$JDK -version
export MINECRAFT_LAUNCHER=$pwd/lib

"$JDK" -server -Duser.home="$HOME" -jar "$LAUNCHER"


